# eric7.Preferences.ConfigurationPages.EditorSearchPage

Module implementing the Editor Search configuration page.

### Global Attributes

None

### Classes

EditorSearchPage | Class implementing the Editor Search configuration page.

### Functions

create | Module function to create the configuration page.

## EditorSearchPage

Class implementing the Editor Search configuration page.

### Derived from

ConfigurationPageBase, Ui_EditorSearchPage

### Class Attributes

None

### Class Methods

None

### Methods

EditorSearchPage | Constructor
save | Public slot to save the Editor Search configuration.

### Static Methods

None

#### EditorSearchPage (Constructor)

EditorSearchPage()

Constructor

#### EditorSearchPage.save

save()

Public slot to save the Editor Search configuration.

Up

## create

create(dlg)

Module function to create the configuration page.

dlg
  reference to the configuration dialog

Return:
  reference to the instantiated page (ConfigurationPageBase)

Up